@@ -11,7 +11,9 @@ from pyvalueobjects.errors.ValueObjectError import ValueObjectError
 # -----------------------------
 
 from pyvalueobjects.numbers.int import Int
+from pyvalueobjects.numbers.nullable_int import NullableInt
 from pyvalueobjects.numbers.positive_int import PositiveInt
 from pyvalueobjects.numbers.negative_int import NegativeInt
+from pyvalueobjects.numbers.nullable_negative_int import NullableNegativeInt
 from pyvalueobjects.numbers.positive_or_zero_int import PositiveOrZeroInt
 from pyvalueobjects.numbers.negative_or_zero_int import NegativeOrZeroInt
